@@ -74,7 +74,7 @@
  *
  * ## Split View Integration
  *
- * When placed inside `AdwNavigationSplitView` or `AdwOverlaySplitView`,
+ * When placed inside [class@NavigationSplitView] or [class@OverlaySplitView],
  * `AdwHeaderBar` will automatically hide the title buttons other than at the
  * edges of the window.
  *
@@ -280,8 +280,6 @@ create_end_controls (AdwHeaderBar *self)
                             self->end_box);
   gtk_box_append (GTK_BOX (self->end_box), controls);
   self->end_controls = controls;
-
-  update_decoration_layout (self, FALSE, TRUE);
 }
 
 static void
@@ -563,8 +561,6 @@ adw_header_bar_unroot (GtkWidget *widget)
 
   g_clear_pointer (&self->split_views, g_slist_free);
 
-  update_title_buttons (self);
-
   GTK_WIDGET_CLASS (adw_header_bar_parent_class)->unroot (widget);
 }
 
