@@ -25,7 +25,7 @@
  * which in turn are represented by [class@PreferencesRow].
  *
  * To summarize the role of the preferences it gathers, a group can have both a
- * title and a description. The title will be used by [class@PreferencesWindow]
+ * title and a description. The title will be used by [class@PreferencesDialog]
  * to let the user look for a preference.
  *
  * ## AdwPreferencesGroup as GtkBuildable
@@ -248,6 +248,7 @@ adw_preferences_group_class_init (AdwPreferencesGroupClass *klass)
   object_class->dispose = adw_preferences_group_dispose;
 
   widget_class->compute_expand = adw_widget_compute_expand;
+  widget_class->focus = adw_widget_focus_child;
 
   /**
    * AdwPreferencesGroup:title: (attributes org.gtk.Property.get=adw_preferences_group_get_title org.gtk.Property.set=adw_preferences_group_set_title)
@@ -508,7 +509,7 @@ adw_preferences_group_set_description (AdwPreferencesGroup *self,
 }
 
 /**
- * adw_preferences_group_get_header_suffix:
+ * adw_preferences_group_get_header_suffix: (attributes org.gtk.Method.get_property=header-suffix)
  * @self: a `AdwPreferencesGroup`
  *
  * Gets the suffix for @self's header.
@@ -530,7 +531,7 @@ adw_preferences_group_get_header_suffix (AdwPreferencesGroup *self)
 }
 
 /**
- * adw_preferences_group_set_header_suffix:
+ * adw_preferences_group_set_header_suffix: (attributes org.gtk.Method.set_property=header-suffix)
  * @self: a `AdwPreferencesGroup`
  * @suffix: (nullable): the suffix to set
  *
@@ -568,6 +569,8 @@ adw_preferences_group_set_header_suffix (AdwPreferencesGroup *self,
     gtk_box_append (priv->header_box, priv->header_suffix);
 
   update_header_visibility (self);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_HEADER_SUFFIX]);
 }
 
 /**
